@@ -2,43 +2,40 @@
 #define MAX_N_RE_MATCHES	16	/* max. number of regex matches: used for coloring matches */
 #define MIN_N_BUFFERLINES	100	/* number of lines to buffer at minimum */
 #define MAX_N_SPAWNED_PROCESSES	16	/* max. nr. of processes executed by matching regexps */
+#define MAX_N_COLUMNS		15	/* max number of columns */
+
+#define LOADAVG_STR_LEN		20
+#define AMOUNT_STR_LEN		(3 + 2 + 1)
 
 #define TERM_MISC	0
 #define TERM_XTERM	1
 
+#define VAL_ZERO_POSITIVE	1	/* >= 0 */
+#define VAL_POSITIVE_NOT_1	2	/* >= 0 && != 1 */
+#define VAL_POSITIVE		3	/* > 0 */
+
+#define M_KB (1024)
+#define M_MB (M_KB * 1024)
+#define M_GB (M_MB * 1024)
+
 #ifndef _BSD_SOURCE
-#define _BSD_SOURCE	/* don't worry: it'll still work if you don't have
-			 * a BSD system
-			 */
+#define _BSD_SOURCE	/* don't worry: it'll still work if you don't have a BSD system */
 #endif
 #ifndef __USE_BSD
 #define __USE_BSD	/* manpage says _BSD_SOURCE, stdlib.h says __USE_BSD */
 #endif
 
-#if defined(__FreeBSD__) || defined(linux) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(sun)
+#include <panel.h>
 #include <ncurses.h>
 #define N_CURSES
-#else
-#include <curses.h>
-#endif
 
 /* Tru64 workaround */
 #if defined(OSF1)
 	#undef getmaxyx
 	#define getmaxyx(w,y,x) y = w->_maxy;  x = w->_maxx
 #endif
-/* HP-UX workaround */
-#if defined(hpux) || defined(__hpux)
-	#undef getmaxy
-	#undef getmaxx
-	#undef getmaxyx
-	#define getmaxx __getmaxx
-	#define getmaxy __getmaxy
-	#define getmaxyx(__win,__y,__x) { WINDOW *__wi; __wi = __win; ((__y) = __getmaxy(__wi), (__x) = __getmaxx(__wi)); }
-#endif
 
-
-#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__)
 #define off64_t off_t
 #define stat64 stat
 #define open64 open
@@ -49,6 +46,17 @@
 #define SEL_SUBWIN	1
 #define SEL_FILES	2
 #define SEL_CSCHEME	3
+#define SEL_COLORS	4
+
+typedef struct
+{
+	WINDOW *win;
+	PANEL *pwin;
+
+	int x_off, y_off;
+	int width, height;
+
+} NEWWIN;
 
 typedef struct
 {
@@ -57,10 +65,27 @@ typedef struct
         char invert_regex;
 	char use_regex;
 
+	int count;
+
 	/* command to run if matches */
 	char *cmd;
 } re;
 
+#define STRIP_TYPE_REGEXP	1
+#define STRIP_TYPE_RANGE	2
+#define STRIP_TYPE_COLUMN	3
+typedef struct
+{
+	int type;
+	
+	regex_t  regexp;
+
+	int start, end;
+
+	int col_nr;
+	char *del;
+} strip_t;
+
 typedef struct _subwindow_
 {
 	char *filename;
@@ -70,9 +95,11 @@ typedef struct _subwindow_
 	int wfd;	/* write */
 	pid_t pid;
 
-	char *incomplete_line;
+	int term_emul;
 
-	char got_a_lf;
+	char paused;
+
+	char *incomplete_line;
 
 	char *win_title;
 
@@ -94,6 +121,7 @@ typedef struct _subwindow_
 	char field_nr;
 	char *field_del;
 	int color_scheme;
+	int color_index;
 
 	char hidden;
 	char follow_filename;
@@ -105,12 +133,15 @@ typedef struct _subwindow_
 	double dev;
 	int n_events;
 
-	WINDOW *status;
-	WINDOW *data;
+	NEWWIN *status;
+	NEWWIN *data;
 
 	int n_re;
 	re *pre;
 
+	int n_strip;
+	strip_t *pstrip;
+
 	struct _subwindow_ *next;
 } proginfo;
 
@@ -153,9 +184,10 @@ typedef struct
 void do_exit(int sig);
 char * select_file(char *input, int what_help);
 char check_no_suppress_lines_filter(proginfo *cur);
-char check_filter(proginfo *cur, char *string, regmatch_t **pmatch, char **error, int *matching_regex);
-void color_print(WINDOW *win, proginfo *cur, unsigned char *string, regmatch_t *matches, int matching_regex);
-int select_window(int what_help);
+void color_print(NEWWIN *win, proginfo *cur, unsigned char *string, regmatch_t *matches, int matching_regex);
+int select_window(int what_help, char *heading);
 void toggle_colors(void);
+char check_filter(proginfo *cur, char *string, regmatch_t **pmatch, char **error, int *matching_regex, char do_re, char *display);
+int wait_for_keypress(int what_help, int max_wait, NEWWIN *popup, char shift_cursor);
 
 void LOG(char *str, ...);
