@@ -13,11 +13,16 @@ int file_info(char *filename, off64_t *file_size, time_t *ts);
 char * convert_regexp_error(int error, const regex_t *preg);
 char check_date(void);
 ssize_t WRITE(int fd, char *whereto, size_t len);
-char * amount_to_str(int amount);
+char * amount_to_str(long long int amount);
 char * replace_string(char *in, int pos_start, int pos_end, char *with_what);
 struct passwd *getuserinfo(void);
 int myopen(char *path, int mode);
 int myclose(int fd);
+#ifdef _DEBUG
+void dump_mem(int sig);
+#endif
+char *abbreviate_filesize(off64_t fsize);
+int file_exist(char *filename);
 
 #define min(x, y) ((x)<(y)?(x):(y))
 #define max(x, y) ((x)>(y)?(x):(y))
